@@ -6,7 +6,7 @@ from edi_835_parser.transaction_set.transaction_set import TransactionSet
 from edi_835_parser.transaction_set.transaction_sets import TransactionSets
 
 
-def parse(path: str) -> TransactionSets:
+def parse(path: str, debug: bool=False) -> TransactionSets:
 	if path[0] == '~':
 		path = os.path.expanduser(path)
 
@@ -15,11 +15,15 @@ def parse(path: str) -> TransactionSets:
 		files = _find_edi_835_files(path)
 		for file in files:
 			file_path = f'{path}/{file}'
-			try:
+			if debug:
 				transaction_set = TransactionSet.build(file_path)
 				transaction_sets.append(transaction_set)
-			except:
-				warn(f'Failed to build a transaction set from {file_path}')
+			else:
+				try:
+					transaction_set = TransactionSet.build(file_path)
+					transaction_sets.append(transaction_set)
+				except:
+					warn(f'Failed to build a transaction set from {file_path}')
 	else:
 		transaction_set = TransactionSet.build(path)
 		transaction_sets.append(transaction_set)
@@ -36,5 +40,4 @@ def _find_edi_835_files(path: str) -> List[str]:
 	return files
 
 if __name__ == '__main__':
-	ts = parse('~/Documents/senscio/Projects/835-parser/edi-835-parser/tests/test_edi_835_files/multiple_paid_claims.txt')
-	print(ts)
+	pass
\ No newline at end of file
