@@ -24,8 +24,27 @@ class TransactionSets:
 		for transaction_set in self:
 			data = pd.concat([data, transaction_set.to_dataframe()])
 
+		data = TransactionSets.sort_columns(data)
 		return data
 
+	@staticmethod
+	def sort_columns(data: pd.DataFrame) -> pd.DataFrame:
+		substrings = ['adj', 'ref', 'rem']
+		variable_columns = [c for c in data.columns if any(sub_string in c for sub_string in substrings)]
+		variable_columns = sorted(variable_columns)
+
+		static_columns = [c for c in data.columns if c not in variable_columns]
+
+		data = data[static_columns + variable_columns]
+		return data
+
+	def sum_payments(self) -> float:
+		amount = 0
+		for transaction_set in self:
+			amount += transaction_set.financial_information.amount_paid
+
+		return amount
+
 	def count_claims(self) -> int:
 		count = 0
 		for transaction_set in self:
